Enumeration
PhoshMonitorTransform
since: 0
Description [src]
The monitors rotation. This corresponds to the values in the org.gnome.Mutter.DisplayConfig DBus protocol.
Available since: 0
Members
PHOSH_MONITOR_TRANSFORM_NORMAL-
Normal.
- Value:
0 - Nickname:
normal - Available since: 0
- Value:
PHOSH_MONITOR_TRANSFORM_90-
90 degree clockwise.
- Value:
1 - Nickname:
90 - Available since: 0
- Value:
PHOSH_MONITOR_TRANSFORM_180-
180 degree clockwise.
- Value:
2 - Nickname:
180 - Available since: 0
- Value:
PHOSH_MONITOR_TRANSFORM_270-
270 degree clockwise.
- Value:
3 - Nickname:
270 - Available since: 0
- Value:
PHOSH_MONITOR_TRANSFORM_FLIPPED-
Flipped clockwise.
- Value:
4 - Nickname:
flipped - Available since: 0
- Value:
PHOSH_MONITOR_TRANSFORM_FLIPPED_90-
Flipped and 90 deg.
- Value:
5 - Nickname:
flipped-90 - Available since: 0
- Value:
PHOSH_MONITOR_TRANSFORM_FLIPPED_180-
Flipped and 180 deg.
- Value:
6 - Nickname:
flipped-180 - Available since: 0
- Value:
PHOSH_MONITOR_TRANSFORM_FLIPPED_270-
Flipped and 270 deg.
- Value:
7 - Nickname:
flipped-270 - Available since: 0
- Value:
Type functions
phosh_monitor_transform_is_tilted
We consider a transform to tilt the display if it changes the display orientation from portrait to landscape or vice versa.
since: 0